@@ -5,10 +5,13 @@ from celerymonitor.listener import EventListener
 class MonitorService(object):
     """celerymon"""
 
-    def __init__(self, logger, http_port=8989):
+    def __init__(self, logger, http_port=8989,
+            http_address=''):
         self.logger = logger
         self.http_port = http_port
+        self.http_address = http_address
 
     def start(self):
-        WebServerThread(port=self.http_port).start()
+        WebServerThread(port=self.http_port,
+                        address=self.http_address).start()
         EventListener().start()
